package ast;

/**
 * An abstract class implemention of IBinOp.  This class encapsulates the
 * invariant behavior of holding two IAST trees, called LHS and RHS.
 */
public abstract class ABinOp implements IBinOp {
    /**
     * The left-hand asbstract syntax tree used by the binary operation.
     */
    private IAST _lhs;
    /**
     * The left-hand asbstract syntax tree used by the binary operation.
     */
    private IAST _rhs;

    /**
     * Protected constructor for this class.   To be called by its children only.
     * @param lhs The left-hand tree of the binary operation.
     * @param rhs The right-hand tree of the binary operation.
     */
    protected ABinOp(IAST lhs, IAST rhs) {
        _lhs = lhs;
        _rhs = rhs;
    }

    /**
     * Accessor method for the left-hand tree.
     * @return The left-hand tree of the binary operation.
     */
    public IAST getLHS() {
        return (_lhs);
    }

    /**
     * Accessor method for the right-hand tree.
     * @return The right-hand tree of the binary operation.
     */
    public IAST getRHS() {
        return (_rhs);
    }
}

