package ast;

import listFW.*;

/**
 * A concrete implementation of the IEnvironment interface that uses a list for
 * internal storage of the id-value  pairs.
 * How the pairs are implemented is left to the implementor (i.e. student).
 */
public class Environment implements IEnvironment {
    private IListFactory _factory;
    private IList _list;

    /**
     * Intializes this Environment to contain a given list factory and an
     * empty list.
     * @param f != null a concrete IListFactory.
     */
    public Environment(IListFactory f) {
        _factory = f;
        _list = _factory.makeEmptyList();
    }

    /**
     * Retrieves the value associated with an id by having the list execute a
     * FindIDAlgo visitor.
     * @param id The id to search the list for.
     * @return The value associated with the id, null if the id doesn't exist
     * in the list.
     */
    public Object getValue(Object id) {
        return _list.execute(FindIDAlgo.Singleton, id);
    }

    /**
     * Stores the id-value pair in the list as a two-element Object pair.
     * @param id The id to store.
     * @param value The value to be associated with the id.
     */
    public void store(Object id, Object value) {
        _list = _factory.makeNEList(new Object[]{id, value}, _list);
    }

    /**
     * Overriden toString() method that returns a String representation of the
     * contents of the list.
     * The EnvToStringAlgo is used to obtain the String representation of the
     * list.
     * @return A String with all the id-value pairs in the enviroment.
     */
    public String toString() {
        return _list.execute(EnvToStringAlgo.Singleton, null).toString();
    }
}

