
package ast;

import listFW.*;

/**
 * Visitor algorithm that will search an IList filled with two-element
 * Object pairs, for the supplied id Object.
 * The value associated with the id is returned or null if no match was found.
 * The id's equals() method is used to check for equality.
 */
public class FindIDAlgo implements IListAlgo {
    /**
     * The singleton instance of this class.
     */
    public static FindIDAlgo Singleton = new FindIDAlgo();
    /**
     * Hidden constructor used by the Singleton.
     */
    private FindIDAlgo() {
    }

    /**
     * Returns null always.
     * @param host Not used.
     * @param param Not used.
     * @return null always.
     */
    public Object emptyCase(IEmptyList host, Object param) {
        return (null);
    }

    /**
     * Checks the id (supplied as the param) against the first element of the
     * two-element Object pair that is assumed to be stored in the host's
     * first.
     * If there is equality, then the second element of the pair
     * (the associated value) is returned.
     * Otherwise, the result of recurring into the host's rest is returned.
     * @param host The INEList that is executing this algorithm.
     * @param param The id that is being searched for.
     * @return The value associated with the supplied id, or null if it wasn't
     * found.
     */
    public Object nonEmptyCase(INEList host, Object param) {
        Object[] dat = (Object[])host.getFirst();
        if(dat[0].equals(param)) return dat[1];
        else return host.getRest().execute(this, param);
    }
}

