package ast;

/**
 * This interface represents an abstract syntax tree.
 * @author Dung X. Nguyen
 * @author Stephen B. Wong
 * @stereotype host
 */
public interface IAST {
    /**
     * Abstract execution of an abstract algorithm on the abstract syntax tree.
     * This is the method that "accepts" the "visitor" algorithm.
     * The appropriate method of the visitor is guaranteed to be called.
     * @param algo the algorithm to be executed.
     * @param param generic input parameter that is passed to the visitor
     * when the appropriate case is called.
     * @return <code>Object</code> output from executing the algorithm algo.
     */
    public abstract Object execute(IASTAlgo algo, Object param);
}

