package ast;

/**
 * This interface defines an abstract visitor algorithm that an abstract syntax
 * tree ("AST") is capable of executing ("accepting").
 * There is a method corresponding to every distinguishable concrete AST class.
 * That is, each distinguishable concrete AST class will call its corresponding
 * method in the algorithm when it executes it.
 * @stereotype visitor
 */
public interface IASTAlgo {
    /**
     * Corresponds to the concrete IntLeaf class in the AST hierarchy.
     * @param host A reference to the host IntLeaf object.
     * @param param A generic input parameter for use by the method.
     * @return The return value of the method.
     */
    public abstract Object intLeafCase(ILeaf host, Object param);

    /**
     * Corresponds to the concrete VarLeaf class in the AST hierarchy.
     * @param host A reference to the host VarLeaf object.
     * @param param A generic input parameter for use by the method.
     * @return The return value of the method.
     */
    public abstract Object varLeafCase(ILeaf host, Object param);

    /**
     * Corresponds to the concrete Add class in the AST hierarchy.
     * @param host A reference to the host Add object.
     * @param param A generic input parameter for use by the method.
     * @return The return value of the method.
     */
    public abstract Object addCase(IBinOp host, Object param);

    /**
     * Corresponds to the concrete Multiply class in the AST hierarchy.
     * @param host A reference to the host Multiply object.
     * @param param A generic input parameter for use by the method.
     * @return The return value of the method.
     */
    public abstract Object multiplyCase(IBinOp host, Object param);
}

