
package ast;

/**
 * This interface represents an abstract environment that contains id-value
 * pairs.
 * An "id" is an identifier that can be substituted for a value when an abstract
 * syntax tree is evaluated.
 */
public interface IEnvironment {
    /**
     * Retrieves the value associated with the supplied id.
     * @param id The id whose associated value is desired.
     * @return The id's associcate value, null if the id does not exist in the environment.
     */
    public abstract Object getValue(Object id);

    /**
     * Stores an id-value pair in the enviroment.
     * @param id The id to store.
     * @param value The value to be associated with the id.
     */
    public abstract void store(Object id, Object value);
}

