
package ast;

/**
 * A concrete binary operation.
 * Note that no sematics about the actual evaluation behavior of this class are
 * defined here.
 * The only concrete distinguishing behavior is that this class will call the
 * multiplyCase() method of any visitor algorithm.
 */
public class Multiply extends ABinOp {
    /**
     * The constructor for this binary operation class.
     * @param lhs The left-hand tree for the operation.
     * @param rhs The right-hand tree for the operation.
     * @SBGen Constructor
     */
    public Multiply(IAST lhs, IAST rhs) {
        super(lhs, rhs);
    }
    /**
     * Executes ("accepts") the supplied algorithm ("visitor") with the supplied
     * input parameter.
     * This method will call the multiplyCase() method of the algo using itself
     * as the host and
     * param as the input parameter.
     * @param algo The visitor algorithm to be accepted.
     * @param param The input parameter for the algo's multiplyuCase() method.
     * @return The return value of the algo.addCase() call.
     */
    public Object execute(IASTAlgo algo, Object param) {
        return algo.multiplyCase(this, param);
    }
}

