package ast;

/**
 * This concrete leaf implementation represents an variable.
 * It's value is thus a String.
 * @author DXN
 * @author SBW
 */
public class VarLeaf implements ILeaf {
    /**
     * The variable.
     */
    private String _id;

    /**
     * The constructor for this class.
     * @param id
     */
    public VarLeaf(String id)  {
        _id = id;
    }

    /**
     * Accessor method for the value held by the leaf.
     * @return The value held.
     */
    public Object getValue() {
        return (_id);
    }

    /**
     * Abstract execution of an abstract algorithm on the abstract syntax tree.
     * This is the method that "accepts" the "visitor" algorithm.
     * The varLeaf case of the algo is called.
     * @param algo The IASTVisitor to be executed.
     * @param param An generic input parameter that is passed to the visitor
     * when the varLeaf case is called.
     * @return The return value of the varLeaf case of the algo.
     */
    public Object execute(IASTAlgo algo, Object param) {
        return algo.varLeafCase(this, param);
    }
}

