
package astAlgos;

import ast.*;

/**
 * This visitor algorithm creates a String representation of the AST in an
 * in-fix format.
 * That is, the binary operations appear between the lhs and rhs AST's.
 * The symbols used to define the binary operations are defined here.
 * <pre>
 * Example:
 * new Add(new IntLeaf(2), new Multiply(new IntLeaf(5), new IntLeaf(7)))
 *     +
 *   /   \
 *  2     *
 *      /   \
 *     5     7
 * </pre>
 * is represented by "(2 + (5 * 7))"
 */
public class InFixFormatter implements IASTAlgo{
    public final static InFixFormatter Singleton = new InFixFormatter();
    private InFixFormatter() {
    }

    /**
     * Returns the String representation of the value of the ILeaf host.
     * @param host The ILeaf object that is executing this algorithm.
     * @param param Not used.
     * @return The String representation of the value of the ILeaf host.
     */
    public Object intLeafCase(ILeaf host, Object param) {
        return host.getValue().toString();
    }

    /**
     * Returns the String representation of the value of the ILeaf host.
     * @param host The ILeaf object that is executing this algorithm.
     * @param param Not used.
     * @return The String representation of the value of the ILeaf host.
     */
    public Object varLeafCase(ILeaf host, Object param) {
        return host.getValue().toString();
    }

    /**
     * Returns the in-fix representation of the addition operation
     * as "( <em>[in-fix of lhs]</em> + <em>[in-fix of rhs]</em>)"
     * @param host The ILeaf object that is executing this algorithm.
     * @param param Not used.
     * @return The in-fix represenation of the AST as a String.
     */
    public Object addCase(IBinOp host, Object param) {
        return "("+ host.getLHS().execute(this, param) +
               " + "+ host.getRHS().execute(this, param) + ")";
    }

    /**
     * Returns the in-fix representation of the multiplication
     * operation as
     * "( <em>[in-fix rep. of lhs]</em> * <em>[in-fix rep. of rhs]</em>)"
     * @param host The ILeaf object that is executing this algorithm.
     * @param param Not used.
     * @return The in-fix represenation of the AST as a String.
     */
    public Object multiplyCase(IBinOp host, Object param) {
        return "("+ host.getLHS().execute(this, param) +
               " * "+ host.getRHS().execute(this, param) + ")";
    }
}

